Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS IoT Events.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, resources, and condition keys for AWS IoT Events - AWS Identity and Access Management

# Actions, resources, and condition keys for AWS IoT Events

Tip

This page is moving to a new location on November 16, 2020. Please update your bookmark to use the new page at https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiotevents.html .

AWS IoT Events (service prefix: `iotevents` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS IoT Events
- Resource types defined by AWS IoT Events
- Condition keys for AWS IoT Events

## Actions defined by AWS IoT Events

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BatchPutMessage | Sends a set of messages to the AWS IoT Events system. | Write | input* |  |
BatchUpdateDetector | Update an detector within the AWS IoT Events system. | Write | input* |  |
CreateDetectorModel | Creates a detector model. | Write | detectorModel* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateInput | Creates an input. | Write | input* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteDetectorModel | Deletes a detector model. | Write | detectorModel* |  |
DeleteInput | Deletes an input. | Write | input* |  |
DescribeDetector | Returns information about the specified detector (instance). | Read | detectorModel* |  |
DescribeDetectorModel | Describes a detector model. | Read | detectorModel* |  |
DescribeInput | Describes an input. | Read | input* |  |
DescribeLoggingOptions | Retrieves the current settings of the AWS IoT Events logging options. | Read |  |  |
ListDetectorModelVersions | Lists all the versions of a detector model. Only the metadata associated with each detector model version is returned. | List | detectorModel* |  |
ListDetectorModels | Lists the detector models you have created. Only the metadata associated with each detector model is returned. | List |  |  |
ListDetectors | Lists detectors (the instances of a detector model). | List | detectorModel* |  |
ListInputs | Lists the inputs you have created. | List |  |  |
ListTagsForResource | Lists the tags (metadata) which you have assigned to the resource. | Read | detectorModel |  |
input |  |
PutLoggingOptions | Sets or updates the AWS IoT Events logging options. | Write |  |  |
TagResource | Adds to or modifies the tags of the given resource. Tags are metadata which can be used to manage a resource. | Tagging | detectorModel |  |
input |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Removes the given tags (metadata) from the resource. | Tagging | detectorModel |  |
input |  |
| aws:TagKeys |
UpdateDetectorModel | Updates a detector model. | Write | detectorModel* |  |
UpdateInput | Updates an input. | Write | input* |  |
UpdateInputRouting | Updates input routing. | Write | input* |  |

## Resource types defined by AWS IoT Events

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
detectorModel | `arn:$ { Partition}:iotevents:$ { Region}:$ { Account}:detectorModel/$ { DetectorModelName}` | aws:ResourceTag/${TagKey}
input | `arn:$ { Partition}:iotevents:$ { Region}:$ { Account}:input/$ { inputName}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS IoT Events

AWS IoT Events defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | A tag key that is present in the request that the user makes to IoT Events. | String
aws:ResourceTag/${TagKey} | The tag key by which a tag value is attached to an IoT Events resource. | String
aws:TagKeys | The list of all the tag key names associated with the IoT Events resource in the request. | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.